@@ -27,7 +27,7 @@ func TestNewDirection(t *testing.T) {
 	for i, u := range passingtests {
 		dir, err := NewDirection(u.value)
 		assert.NoError(t, err)
-		assert.Equal(t, u.expected, dir, "%d: %+v", i, u)
+		assert.Equalf(t, u.expected, dir, "%d: %+v", i, u)
 	}
 	for _, u := range failingtests {
 		_, err := NewDirection(u)
@@ -48,6 +48,6 @@ func TestDirection_String(t *testing.T) {
 	}
 
 	for i, u := range tests {
-		assert.Equal(t, u.expected, u.actual.String(), "%d: %+v", i, u)
+		assert.Equalf(t, u.expected, u.actual.String(), "%d: %+v", i, u)
 	}
 }
