@@ -23,6 +23,7 @@ const (
 	AttrKeyConnectionSetup  = "setup"
 	AttrKeyMID              = "mid"
 	AttrKeyICELite          = "ice-lite"
+	AttrKeyICEOptions       = "ice-options"
 	AttrKeyRTCPMux          = "rtcp-mux"
 	AttrKeyRTCPRsize        = "rtcp-rsize"
 	AttrKeyInactive         = "inactive"
@@ -31,6 +32,7 @@ const (
 	AttrKeySendRecv         = "sendrecv"
 	AttrKeyExtMap           = "extmap"
 	AttrKeyExtMapAllowMixed = "extmap-allow-mixed"
+	AttrKeyCryptex          = "cryptex"
 )
 
 // Constants for semantic tokens used in JSEP.
@@ -38,7 +40,9 @@ const (
 	SemanticTokenLipSynchronization     = "LS"
 	SemanticTokenFlowIdentification     = "FID"
 	SemanticTokenForwardErrorCorrection = "FEC"
-	SemanticTokenWebRTCMediaStreams     = "WMS"
+	// https://datatracker.ietf.org/doc/html/rfc5956#section-4.1
+	SemanticTokenForwardErrorCorrectionFramework = "FEC-FR"
+	SemanticTokenWebRTCMediaStreams              = "WMS"
 )
 
 // Constants for extmap key.
@@ -113,6 +117,36 @@ func (s *SessionDescription) WithValueAttribute(key, value string) *SessionDescr
 	return s
 }
 
+// addOrUpdateICEOption adds or updates the ice-options attribute with the given value.
+func (s *SessionDescription) addOrUpdateICEOption(value string) *SessionDescription {
+	for i := range s.Attributes {
+		if s.Attributes[i].Key == AttrKeyICEOptions {
+			prefix := " "
+			if s.Attributes[i].Value == "" {
+				prefix = ""
+			}
+
+			s.Attributes[i].Value += prefix + value
+
+			return s
+		}
+	}
+
+	return s.WithValueAttribute(AttrKeyICEOptions, value)
+}
+
+// WithICETrickleAdvertised advertises ICE trickle support in the session description.
+// See https://datatracker.ietf.org/doc/html/rfc9429#section-5.2.1
+func (s *SessionDescription) WithICETrickleAdvertised() *SessionDescription {
+	return s.addOrUpdateICEOption("trickle")
+}
+
+// WithICERenomination advertises ICE renomination support in the session description.
+// See https://datatracker.ietf.org/doc/html/draft-thatcher-ice-renomination-01#section-3
+func (s *SessionDescription) WithICERenomination() *SessionDescription {
+	return s.addOrUpdateICEOption("renomination")
+}
+
 // WithFingerprint adds a fingerprint to the session description.
 func (s *SessionDescription) WithFingerprint(algorithm, value string) *SessionDescription {
 	return s.WithValueAttribute("fingerprint", algorithm+" "+value)
